@@ -1,9 +1,9 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-01-27 16:08:25 mtw>
+# Last changed Time-stamp: <2015-02-06 16:29:16 mtw>
 
 package Bio::ViennaNGS::Expression;
 
-use version; our $VERSION = qv('0.12_13');
+use version; our $VERSION = qv('0.12_15');
 use Moose;
 use Carp;
 use Data::Dumper;
@@ -200,14 +200,14 @@ read-count based gene expression
   my $expression = Bio::ViennaNGS::Expression->new();
 
   # parse read counts from an extended BED12 file
-  $expression->>parse_readcounts_bed12("$bed12");
+  $expression->parse_readcounts_bed12("$bed12");
 
   # compute normalized expression of ith sample in Transcript per Million (TPM)
   $expression->computeTPM($i, $readlength);
 
   # write extended BED12 file with TPM for each condition past
   # the 12th column
-  $expression->>write_expression_bed12("TPM", $dest, $basename);
+  $expression->write_expression_bed12("TPM", $dest, $basename);
 
 =head1 DESCRIPTION
 
@@ -222,11 +222,11 @@ transcript expression from read counts.
 
 Title : parse_readcounts_bed12
 
-Usage : C<<$obj->parse_readcounts_bed12($file);>>
+Usage : C<$obj-E<gt>parse_readcounts_bed12($file);>
 
 Function : Parses a bedtools multicov (multiBamCov) file, i.e. an
            extended BED12 file, into an Array of Hash of Hashes data
-           structure (C<<@{$self->data}>>).
+           structure (C<@{$self-E<gt>data}>).
 
 Args : C<$file> is the input file, i.e. and extended BED12 file where
        each column past the 12th lists read counts for this bedline's
@@ -237,8 +237,8 @@ Returns :
 Notes : This method evaluates the number of samples/conditions present
         in the input, i.e. the number of columns extending the
         canonical BED12 columns in the input multicov file and
-        populates C<<$self->conds>>. Also populates
-        C<<$self->nr_features>> with the number of genes/features
+        populates C<$self-E<gt>conds>. Also populates
+        C<$self-E<gt>nr_features> with the number of genes/features
         present in the input (evidently, this should be the same for
         each sample/condition in the input).
 
@@ -246,10 +246,10 @@ Notes : This method evaluates the number of samples/conditions present
 
 Title : computeTPM
 
-Usage : C<<$obj-E<gt>computeTPM($sample, $readlength);>>
+Usage : C<$obj-E<gt>computeTPM($sample, $readlength);>
 
 Function : Computes expression of each gene/feature present in
-           C<<$self->data>> in Transcript per Million (TPM) [Wagner
+           C<$self-E<gt>data> in Transcript per Million (TPM) [Wagner
            et.al. Theory Biosci. (2012)].  is a reference to a Hash of
            Hashes data straucture where keys are feature names and
            values hold a hash that must at least contain length and
@@ -257,7 +257,7 @@ Function : Computes expression of each gene/feature present in
            represented by _one_ element of C<@featCount>, which is
            populated from a multicov file by C<parse_multicov()>.
 
-Args : C<$sample> is the sample index of C<<@{$self->data}>>. This is
+Args : C<$sample> is the sample index of C<@{$self-E<gt>data}>. This is
         especially handy if one is only interested in computing
         normalized expression values for a specific sample, rather
         than all samples in multicov BED12 file. C<$readlength> is the
@@ -272,17 +272,18 @@ Returns : Returns the mean TPM of the processed sample, which is
 
 Title : write_expression_bed12
 
-Usage : C<<$obj-E<gt>write_expression_bed12($measure, $dest,
-$basename);>>
+Usage : C<$obj-E<gt>write_expression_bed12($measure,
+$dest,$basename);>
 
 Function : Writes normalized expression data to a bedtools multicov
            (multiBamCov)-type BED12 file.
 
 Args : C<$measure> specifies the type in which normalized expression
-       data from C<<@{$self-->data}>> is dumped, i.e. TPM or
-       RPKM. These values must have been computed and inserted into
-       C<<@{self->data}>> beforehand by
-       e.g. C<<$self->computeTPM()>>. C<$dest> and C<$base_name>
+       data from C<@{$self-E<gt>data}> is dumped. Currently supports
+       'TPM', however 'RPKM' support will be added in a future
+       release. These values must have been computed and inserted into
+       C<@{self-E<gt>data}> beforehand by
+       e.g. C<$self-E<gt>computeTPM()>. C<$dest> and C<$base_name>
        give path and base name of the output file, respectively.
 
 Returns : None. The output is position-sorted extended BED12 file.
