@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 # -*-CPerl-*-
-# Last changed Time-stamp: <2014-12-14 23:42:49 mtw>
+# Last changed Time-stamp: <2015-01-26 00:38:37 mtw>
 #
 # Compute normalized expression data in TPM from (raw) read
 # counts in multicov.
@@ -11,7 +11,7 @@
 # ***********************************************************************
 # *  Copyright notice
 # *
-# *  Copyright 2014 Michael T. Wolfinger <michael@wolfinger.eu>
+# *  Copyright 2015 Michael T. Wolfinger <michael@wolfinger.eu>
 # *  All rights reserved
 # *
 # *  This program is free software: you can redistribute it and/or modify
@@ -38,14 +38,14 @@ use File::Basename;
 use Pod::Usage;
 use Cwd;
 use Path::Class;
-use Bio::ViennaNGS::Util qw( parse_multicov write_multicov featCount_data computeTPM);
+use Bio::ViennaNGS::Expression;
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 #^^^^^^^^^^ Variables ^^^^^^^^^^^#
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 my ($infile,$FC,$FC_sample,$conds,$totreads,$i,$sample,$basename,$dir,$ext,$cwd);
 my $readlength  = 100;
-my $dest = getcwd();;
+my $dest = getcwd();
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 #^^^^^^^^^^^^^^ Main ^^^^^^^^^^^^^#
@@ -68,21 +68,18 @@ unless ($dest =~ /\/$/){$dest .= "/";}
 unless (-d $dest){mkdir $dest;}
 ($basename,$dir,$ext) = fileparse($infile,qr/\.[^.]*/);
 
-# parse multicov file; populate @featCount
-$conds = parse_multicov($infile);
-$FC = featCount_data();
-#print Dumper($FC);
-#print "parsing $infile: $conds conditions found\n";
+# parse multicov file
+my $exp = Bio::ViennaNGS::Expression->new();
+$exp->parse_readcounts_bed12("$infile"); # stringified Path::Class object
+#print Dumper($exp->nr_features);
 
-# extract hash for a specific sample from $FC
-for ($i=0;$i<$conds;$i++){
-  my $meanTPM;
-  $FC_sample = @$FC[$i];
-  $meanTPM = computeTPM($FC_sample, $readlength);
+# compute TPM values for all genes in each condition
+for ($i=0;$i<$exp->conds;$i++){
+  $exp->computeTPM($i, $readlength);
 }
 
-# write multicov file based on TPM data in @featCount
-write_multicov("TPM", $dest, $basename);
+# write extended BED12 file with TPM for each condition after column 12
+$exp->write_expression_bed12("TPM", $dest, $basename);
 
 __END__
 
@@ -101,17 +98,17 @@ normalize_multicov.pl [-i I<FILE>] [--readlength I<INT>] [options]
 This program computes normalized expression values in Transcript per
 Million (TPM) from read counts. The latter must be provided in the
 format produced by the 'bedtools multicov' utility, i.e. an extended
-BED6 file where each colum past the 6th lists the read counts for one
+BED12 file where each colum past the 12th lists read counts for one
 sample/condition.
 
-=head1 OPTION
+=head1 OPTIONS
 
 =over
 
 =item B<-i>
 
-Input file in 'bedtools multicov' output format, i.e. an extended BED6
-file where each colum past the 6th lists the read counts for one
+Input file in 'bedtools multicov' output format, i.e. an extended BED12
+file where each colum past the 12th lists the read counts for one
 sample/condition.
 
 =item B<--readlength -r>
